@@ -62,6 +62,26 @@ class BeoPlay(object):
         self.standPositions = []
         self.standPositionsID = []
 
+    @property
+    def name(self):
+        """Return the device name."""
+        return self._name
+
+    @property
+    def serialNumber(self):
+        """Return the device serial number."""
+        return self._serialNumber
+
+    @property
+    def itemNumber(self):
+        """Return the device serial number."""
+        return self._itemNumber
+
+    @property
+    def typeNumber(self):
+        """Return the device serial number."""
+        return self._typeNumber
+
     ###############################################################
     # ASYNC BASED NETWORK CALLS
     ###############################################################
@@ -496,14 +516,14 @@ class BeoPlay(object):
     # PARSE NOTIFICATIONS MESSAGES
     ###############################################################
 
-    def getVolume(self, data):
+    def _processVolume(self, data):
         if data["notification"]["type"] == "VOLUME" and data["notification"]["data"] is not None:
             self.volume = int(data["notification"]["data"]["speaker"]["level"])/100
             self.min_volume = int(data["notification"]["data"]["speaker"]["range"]["minimum"])/100
             self.max_volume = int(data["notification"]["data"]["speaker"]["range"]["maximum"])/100
             self.muted = data["notification"]["data"]["speaker"]["muted"]
 
-    def getSource(self, data):
+    def _processSource(self, data):
         if data["notification"]["type"] == "SOURCE" and data["notification"]["data"] is not None:
             if not data["notification"]["data"]:
                 self.source = None
@@ -521,16 +541,16 @@ class BeoPlay(object):
             self.media_country = None
             self.media_languages = None
 
-    def getPrimaryExperience(self, data):
+    def _processPrimaryExperience(self, data):
         if data["notification"]["type"] == "SOURCE":
             self.primary_experience = data["primary"]
 
-    def getState(self, data):
+    def _processState(self, data):
         if data["notification"]["type"] == "PROGRESS_INFORMATION" and data["notification"]["data"]  is not None:
             self.state = data["notification"]["data"]["state"]
             self.on = True
 
-    def getMusicInfo(self, data):
+    def _processMusicInfo(self, data):
         if data["notification"]["type"] == "NOW_PLAYING_STORED_MUSIC":
             if data["notification"]["data"]["trackImage"]:
                 self.media_url = data["notification"]["data"]["trackImage"][0]["url"]
@@ -591,13 +611,13 @@ class BeoPlay(object):
         """ Cumulative process all the potential notification information. """
         try:
             # get volume
-            self.getVolume(data)
+            self._processVolume(data)
             # get source
-            self.getSource(data)
+            self._processSource(data)
             # get state
-            self.getState(data)
+            self._processState(data)
             # get currently playing music info
-            self.getMusicInfo(data)
+            self._processMusicInfo(data)
         except KeyError:
             LOG.debug("Malformed notification: %s", str(data))
 
